pybedtools.scripts.intersection_matrix
======================================

.. automodule:: pybedtools.scripts.intersection_matrix

   
   
   .. rubric:: Functions

   .. autosummary::
   
      actual_intersection
      create_matrix
      enrichment_score
      example_filename
      frac_of_a
      get_name
      main
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
   
      BedTool
   
   

   
   
   